<a id="types-aiobotocore-elasticache"></a>

# types-aiobotocore-elasticache

[![PyPI - types-aiobotocore-elasticache](https://img.shields.io/pypi/v/types-aiobotocore-elasticache.svg?color=blue)](https://pypi.org/project/types-aiobotocore-elasticache)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-elasticache.svg?color=blue)](https://pypi.org/project/types-aiobotocore-elasticache)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-elasticache?color=blue)](https://pypistats.org/packages/types-aiobotocore-elasticache)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.ElastiCache 2.3.1](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elasticache.html#ElastiCache)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.5.14](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-elasticache docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_elasticache/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-elasticache](#types-aiobotocore-elasticache)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `ElastiCache`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `ElastiCache` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[elasticache]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[elasticache]'


# standalone installation
python -m pip install types-aiobotocore-elasticache
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-elasticache
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[elasticache]` in your environment:

```bash
python -m pip install 'types-aiobotocore[elasticache]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[elasticache]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[elasticache]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[elasticache]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[elasticache]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[elasticache]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[elasticache]` in your environment:

```bash
python -m pip install 'types-aiobotocore[elasticache]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[elasticache]` in your environment:

```bash
python -m pip install 'types-aiobotocore[elasticache]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ElastiCacheClient` provides annotations for
`session.create_client("elasticache")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_elasticache import ElastiCacheClient

session = get_session()
async with session.create_client("elasticache") as client:
    client: ElastiCacheClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_elasticache.paginator` module contains type annotations for
all paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_elasticache import ElastiCacheClient
from types_aiobotocore_elasticache.paginator import (
    DescribeCacheClustersPaginator,
    DescribeCacheEngineVersionsPaginator,
    DescribeCacheParameterGroupsPaginator,
    DescribeCacheParametersPaginator,
    DescribeCacheSecurityGroupsPaginator,
    DescribeCacheSubnetGroupsPaginator,
    DescribeEngineDefaultParametersPaginator,
    DescribeEventsPaginator,
    DescribeGlobalReplicationGroupsPaginator,
    DescribeReplicationGroupsPaginator,
    DescribeReservedCacheNodesPaginator,
    DescribeReservedCacheNodesOfferingsPaginator,
    DescribeServiceUpdatesPaginator,
    DescribeSnapshotsPaginator,
    DescribeUpdateActionsPaginator,
    DescribeUserGroupsPaginator,
    DescribeUsersPaginator,
)

session = get_session()
async with session.create_client("elasticache") as client:
    client: ElastiCacheClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        describe_cache_clusters_paginator: DescribeCacheClustersPaginator = client.get_paginator("describe_cache_clusters")
        describe_cache_engine_versions_paginator: DescribeCacheEngineVersionsPaginator = client.get_paginator("describe_cache_engine_versions")
        describe_cache_parameter_groups_paginator: DescribeCacheParameterGroupsPaginator = client.get_paginator("describe_cache_parameter_groups")
        describe_cache_parameters_paginator: DescribeCacheParametersPaginator = client.get_paginator("describe_cache_parameters")
        describe_cache_security_groups_paginator: DescribeCacheSecurityGroupsPaginator = client.get_paginator("describe_cache_security_groups")
        describe_cache_subnet_groups_paginator: DescribeCacheSubnetGroupsPaginator = client.get_paginator("describe_cache_subnet_groups")
        describe_engine_default_parameters_paginator: DescribeEngineDefaultParametersPaginator = client.get_paginator("describe_engine_default_parameters")
        describe_events_paginator: DescribeEventsPaginator = client.get_paginator("describe_events")
        describe_global_replication_groups_paginator: DescribeGlobalReplicationGroupsPaginator = client.get_paginator("describe_global_replication_groups")
        describe_replication_groups_paginator: DescribeReplicationGroupsPaginator = client.get_paginator("describe_replication_groups")
        describe_reserved_cache_nodes_paginator: DescribeReservedCacheNodesPaginator = client.get_paginator("describe_reserved_cache_nodes")
        describe_reserved_cache_nodes_offerings_paginator: DescribeReservedCacheNodesOfferingsPaginator = client.get_paginator("describe_reserved_cache_nodes_offerings")
        describe_service_updates_paginator: DescribeServiceUpdatesPaginator = client.get_paginator("describe_service_updates")
        describe_snapshots_paginator: DescribeSnapshotsPaginator = client.get_paginator("describe_snapshots")
        describe_update_actions_paginator: DescribeUpdateActionsPaginator = client.get_paginator("describe_update_actions")
        describe_user_groups_paginator: DescribeUserGroupsPaginator = client.get_paginator("describe_user_groups")
        describe_users_paginator: DescribeUsersPaginator = client.get_paginator("describe_users")
    ```


### Waiters annotations

`types_aiobotocore_elasticache.waiter` module contains type annotations for all waiters.

```python
from aiobotocore.session import get_session

from types_aiobotocore_elasticache.client import ElastiCacheClient
from types_aiobotocore_elasticache.waiter import (
    CacheClusterAvailableWaiter,
    CacheClusterDeletedWaiter,
    ReplicationGroupAvailableWaiter,
    ReplicationGroupDeletedWaiter,
)

session = get_session()
async with session.create_client("elasticache") as client:
    client: ElastiCacheClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        cache_cluster_available_waiter: CacheClusterAvailableWaiter = client.get_waiter("cache_cluster_available")
        cache_cluster_deleted_waiter: CacheClusterDeletedWaiter = client.get_waiter("cache_cluster_deleted")
        replication_group_available_waiter: ReplicationGroupAvailableWaiter = client.get_waiter("replication_group_available")
        replication_group_deleted_waiter: ReplicationGroupDeletedWaiter = client.get_waiter("replication_group_deleted")
    ```





<a id="literals"></a>

### Literals

`types_aiobotocore_elasticache.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_elasticache.literals import (
    AZModeType,
    AuthTokenUpdateStatusType,
    AuthTokenUpdateStrategyTypeType,
    AuthenticationTypeType,
    AutomaticFailoverStatusType,
    CacheClusterAvailableWaiterName,
    CacheClusterDeletedWaiterName,
    ChangeTypeType,
    DataTieringStatusType,
    DescribeCacheClustersPaginatorName,
    DescribeCacheEngineVersionsPaginatorName,
    DescribeCacheParameterGroupsPaginatorName,
    DescribeCacheParametersPaginatorName,
    DescribeCacheSecurityGroupsPaginatorName,
    DescribeCacheSubnetGroupsPaginatorName,
    DescribeEngineDefaultParametersPaginatorName,
    DescribeEventsPaginatorName,
    DescribeGlobalReplicationGroupsPaginatorName,
    DescribeReplicationGroupsPaginatorName,
    DescribeReservedCacheNodesOfferingsPaginatorName,
    DescribeReservedCacheNodesPaginatorName,
    DescribeServiceUpdatesPaginatorName,
    DescribeSnapshotsPaginatorName,
    DescribeUpdateActionsPaginatorName,
    DescribeUserGroupsPaginatorName,
    DescribeUsersPaginatorName,
    DestinationTypeType,
    LogDeliveryConfigurationStatusType,
    LogFormatType,
    LogTypeType,
    MultiAZStatusType,
    NodeUpdateInitiatedByType,
    NodeUpdateStatusType,
    OutpostModeType,
    PendingAutomaticFailoverStatusType,
    ReplicationGroupAvailableWaiterName,
    ReplicationGroupDeletedWaiterName,
    ServiceUpdateSeverityType,
    ServiceUpdateStatusType,
    ServiceUpdateTypeType,
    SlaMetType,
    SourceTypeType,
    UpdateActionStatusType,
    ElastiCacheServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    WaiterName,
    RegionName,
)

def check_value(value: AZModeType) -> bool:
    ...
````

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_elasticache.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_elasticache.type_defs import (
    AddTagsToResourceMessageRequestTypeDef,
    AllowedNodeTypeModificationsMessageTypeDef,
    AuthenticationTypeDef,
    AuthorizeCacheSecurityGroupIngressMessageRequestTypeDef,
    AuthorizeCacheSecurityGroupIngressResultTypeDef,
    AvailabilityZoneTypeDef,
    BatchApplyUpdateActionMessageRequestTypeDef,
    BatchStopUpdateActionMessageRequestTypeDef,
    CacheClusterMessageTypeDef,
    CacheClusterTypeDef,
    CacheEngineVersionMessageTypeDef,
    CacheEngineVersionTypeDef,
    CacheNodeTypeDef,
    CacheNodeTypeSpecificParameterTypeDef,
    CacheNodeTypeSpecificValueTypeDef,
    CacheNodeUpdateStatusTypeDef,
    CacheParameterGroupDetailsTypeDef,
    CacheParameterGroupNameMessageTypeDef,
    CacheParameterGroupStatusTypeDef,
    CacheParameterGroupTypeDef,
    CacheParameterGroupsMessageTypeDef,
    CacheSecurityGroupMembershipTypeDef,
    CacheSecurityGroupMessageTypeDef,
    CacheSecurityGroupTypeDef,
    CacheSubnetGroupMessageTypeDef,
    CacheSubnetGroupTypeDef,
    CloudWatchLogsDestinationDetailsTypeDef,
    CompleteMigrationMessageRequestTypeDef,
    CompleteMigrationResponseTypeDef,
    ConfigureShardTypeDef,
    CopySnapshotMessageRequestTypeDef,
    CopySnapshotResultTypeDef,
    CreateCacheClusterMessageRequestTypeDef,
    CreateCacheClusterResultTypeDef,
    CreateCacheParameterGroupMessageRequestTypeDef,
    CreateCacheParameterGroupResultTypeDef,
    CreateCacheSecurityGroupMessageRequestTypeDef,
    CreateCacheSecurityGroupResultTypeDef,
    CreateCacheSubnetGroupMessageRequestTypeDef,
    CreateCacheSubnetGroupResultTypeDef,
    CreateGlobalReplicationGroupMessageRequestTypeDef,
    CreateGlobalReplicationGroupResultTypeDef,
    CreateReplicationGroupMessageRequestTypeDef,
    CreateReplicationGroupResultTypeDef,
    CreateSnapshotMessageRequestTypeDef,
    CreateSnapshotResultTypeDef,
    CreateUserGroupMessageRequestTypeDef,
    CreateUserMessageRequestTypeDef,
    CustomerNodeEndpointTypeDef,
    DecreaseNodeGroupsInGlobalReplicationGroupMessageRequestTypeDef,
    DecreaseNodeGroupsInGlobalReplicationGroupResultTypeDef,
    DecreaseReplicaCountMessageRequestTypeDef,
    DecreaseReplicaCountResultTypeDef,
    DeleteCacheClusterMessageRequestTypeDef,
    DeleteCacheClusterResultTypeDef,
    DeleteCacheParameterGroupMessageRequestTypeDef,
    DeleteCacheSecurityGroupMessageRequestTypeDef,
    DeleteCacheSubnetGroupMessageRequestTypeDef,
    DeleteGlobalReplicationGroupMessageRequestTypeDef,
    DeleteGlobalReplicationGroupResultTypeDef,
    DeleteReplicationGroupMessageRequestTypeDef,
    DeleteReplicationGroupResultTypeDef,
    DeleteSnapshotMessageRequestTypeDef,
    DeleteSnapshotResultTypeDef,
    DeleteUserGroupMessageRequestTypeDef,
    DeleteUserMessageRequestTypeDef,
    DescribeCacheClustersMessageCacheClusterAvailableWaitTypeDef,
    DescribeCacheClustersMessageCacheClusterDeletedWaitTypeDef,
    DescribeCacheClustersMessageDescribeCacheClustersPaginateTypeDef,
    DescribeCacheClustersMessageRequestTypeDef,
    DescribeCacheEngineVersionsMessageDescribeCacheEngineVersionsPaginateTypeDef,
    DescribeCacheEngineVersionsMessageRequestTypeDef,
    DescribeCacheParameterGroupsMessageDescribeCacheParameterGroupsPaginateTypeDef,
    DescribeCacheParameterGroupsMessageRequestTypeDef,
    DescribeCacheParametersMessageDescribeCacheParametersPaginateTypeDef,
    DescribeCacheParametersMessageRequestTypeDef,
    DescribeCacheSecurityGroupsMessageDescribeCacheSecurityGroupsPaginateTypeDef,
    DescribeCacheSecurityGroupsMessageRequestTypeDef,
    DescribeCacheSubnetGroupsMessageDescribeCacheSubnetGroupsPaginateTypeDef,
    DescribeCacheSubnetGroupsMessageRequestTypeDef,
    DescribeEngineDefaultParametersMessageDescribeEngineDefaultParametersPaginateTypeDef,
    DescribeEngineDefaultParametersMessageRequestTypeDef,
    DescribeEngineDefaultParametersResultTypeDef,
    DescribeEventsMessageDescribeEventsPaginateTypeDef,
    DescribeEventsMessageRequestTypeDef,
    DescribeGlobalReplicationGroupsMessageDescribeGlobalReplicationGroupsPaginateTypeDef,
    DescribeGlobalReplicationGroupsMessageRequestTypeDef,
    DescribeGlobalReplicationGroupsResultTypeDef,
    DescribeReplicationGroupsMessageDescribeReplicationGroupsPaginateTypeDef,
    DescribeReplicationGroupsMessageReplicationGroupAvailableWaitTypeDef,
    DescribeReplicationGroupsMessageReplicationGroupDeletedWaitTypeDef,
    DescribeReplicationGroupsMessageRequestTypeDef,
    DescribeReservedCacheNodesMessageDescribeReservedCacheNodesPaginateTypeDef,
    DescribeReservedCacheNodesMessageRequestTypeDef,
    DescribeReservedCacheNodesOfferingsMessageDescribeReservedCacheNodesOfferingsPaginateTypeDef,
    DescribeReservedCacheNodesOfferingsMessageRequestTypeDef,
    DescribeServiceUpdatesMessageDescribeServiceUpdatesPaginateTypeDef,
    DescribeServiceUpdatesMessageRequestTypeDef,
    DescribeSnapshotsListMessageTypeDef,
    DescribeSnapshotsMessageDescribeSnapshotsPaginateTypeDef,
    DescribeSnapshotsMessageRequestTypeDef,
    DescribeUpdateActionsMessageDescribeUpdateActionsPaginateTypeDef,
    DescribeUpdateActionsMessageRequestTypeDef,
    DescribeUserGroupsMessageDescribeUserGroupsPaginateTypeDef,
    DescribeUserGroupsMessageRequestTypeDef,
    DescribeUserGroupsResultTypeDef,
    DescribeUsersMessageDescribeUsersPaginateTypeDef,
    DescribeUsersMessageRequestTypeDef,
    DescribeUsersResultTypeDef,
    DestinationDetailsTypeDef,
    DisassociateGlobalReplicationGroupMessageRequestTypeDef,
    DisassociateGlobalReplicationGroupResultTypeDef,
    EC2SecurityGroupTypeDef,
    EndpointTypeDef,
    EngineDefaultsTypeDef,
    EventTypeDef,
    EventsMessageTypeDef,
    FailoverGlobalReplicationGroupMessageRequestTypeDef,
    FailoverGlobalReplicationGroupResultTypeDef,
    FilterTypeDef,
    GlobalNodeGroupTypeDef,
    GlobalReplicationGroupInfoTypeDef,
    GlobalReplicationGroupMemberTypeDef,
    GlobalReplicationGroupTypeDef,
    IncreaseNodeGroupsInGlobalReplicationGroupMessageRequestTypeDef,
    IncreaseNodeGroupsInGlobalReplicationGroupResultTypeDef,
    IncreaseReplicaCountMessageRequestTypeDef,
    IncreaseReplicaCountResultTypeDef,
    KinesisFirehoseDestinationDetailsTypeDef,
    ListAllowedNodeTypeModificationsMessageRequestTypeDef,
    ListTagsForResourceMessageRequestTypeDef,
    LogDeliveryConfigurationRequestTypeDef,
    LogDeliveryConfigurationTypeDef,
    ModifyCacheClusterMessageRequestTypeDef,
    ModifyCacheClusterResultTypeDef,
    ModifyCacheParameterGroupMessageRequestTypeDef,
    ModifyCacheSubnetGroupMessageRequestTypeDef,
    ModifyCacheSubnetGroupResultTypeDef,
    ModifyGlobalReplicationGroupMessageRequestTypeDef,
    ModifyGlobalReplicationGroupResultTypeDef,
    ModifyReplicationGroupMessageRequestTypeDef,
    ModifyReplicationGroupResultTypeDef,
    ModifyReplicationGroupShardConfigurationMessageRequestTypeDef,
    ModifyReplicationGroupShardConfigurationResultTypeDef,
    ModifyUserGroupMessageRequestTypeDef,
    ModifyUserMessageRequestTypeDef,
    NodeGroupConfigurationTypeDef,
    NodeGroupMemberTypeDef,
    NodeGroupMemberUpdateStatusTypeDef,
    NodeGroupTypeDef,
    NodeGroupUpdateStatusTypeDef,
    NodeSnapshotTypeDef,
    NotificationConfigurationTypeDef,
    PaginatorConfigTypeDef,
    ParameterNameValueTypeDef,
    ParameterTypeDef,
    PendingLogDeliveryConfigurationTypeDef,
    PendingModifiedValuesTypeDef,
    ProcessedUpdateActionTypeDef,
    PurchaseReservedCacheNodesOfferingMessageRequestTypeDef,
    PurchaseReservedCacheNodesOfferingResultTypeDef,
    RebalanceSlotsInGlobalReplicationGroupMessageRequestTypeDef,
    RebalanceSlotsInGlobalReplicationGroupResultTypeDef,
    RebootCacheClusterMessageRequestTypeDef,
    RebootCacheClusterResultTypeDef,
    RecurringChargeTypeDef,
    RegionalConfigurationTypeDef,
    RemoveTagsFromResourceMessageRequestTypeDef,
    ReplicationGroupMessageTypeDef,
    ReplicationGroupPendingModifiedValuesTypeDef,
    ReplicationGroupTypeDef,
    ReservedCacheNodeMessageTypeDef,
    ReservedCacheNodeTypeDef,
    ReservedCacheNodesOfferingMessageTypeDef,
    ReservedCacheNodesOfferingTypeDef,
    ResetCacheParameterGroupMessageRequestTypeDef,
    ReshardingConfigurationTypeDef,
    ReshardingStatusTypeDef,
    ResponseMetadataTypeDef,
    RevokeCacheSecurityGroupIngressMessageRequestTypeDef,
    RevokeCacheSecurityGroupIngressResultTypeDef,
    SecurityGroupMembershipTypeDef,
    ServiceUpdateTypeDef,
    ServiceUpdatesMessageTypeDef,
    SlotMigrationTypeDef,
    SnapshotTypeDef,
    StartMigrationMessageRequestTypeDef,
    StartMigrationResponseTypeDef,
    SubnetOutpostTypeDef,
    SubnetTypeDef,
    TagListMessageTypeDef,
    TagTypeDef,
    TestFailoverMessageRequestTypeDef,
    TestFailoverResultTypeDef,
    TimeRangeFilterTypeDef,
    UnprocessedUpdateActionTypeDef,
    UpdateActionResultsMessageTypeDef,
    UpdateActionTypeDef,
    UpdateActionsMessageTypeDef,
    UserGroupPendingChangesTypeDef,
    UserGroupResponseMetadataTypeDef,
    UserGroupTypeDef,
    UserGroupsUpdateStatusTypeDef,
    UserResponseMetadataTypeDef,
    UserTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> AddTagsToResourceMessageRequestTypeDef:
    return {
      ...
    }
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-elasticache` version is the same as related `aiobotocore`
version and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/)
format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_elasticache/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
